==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/VMwareToAzStackHCIPolicyModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMware To AzStackHCI Policy model custom properties.
 * @property appConsistentFrequencyInMinutes Gets or sets the app consistent snapshot frequency (in minutes).
 * @property crashConsistentFrequencyInMinutes Gets or sets the crash consistent snapshot frequency (in minutes).
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'VMwareToAzStackHCI'.
 * @property recoveryPointHistoryInMinutes Gets or sets the duration in minutes until which the recovery points need to be
 * stored.
 */
public data class VMwareToAzStackHCIPolicyModelCustomPropertiesArgs(
    public val appConsistentFrequencyInMinutes: Output<Int>,
    public val crashConsistentFrequencyInMinutes: Output<Int>,
    public val instanceType: Output<String>,
    public val recoveryPointHistoryInMinutes: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs.builder()
            .appConsistentFrequencyInMinutes(appConsistentFrequencyInMinutes.applyValue({ args0 -> args0 }))
            .crashConsistentFrequencyInMinutes(crashConsistentFrequencyInMinutes.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .recoveryPointHistoryInMinutes(recoveryPointHistoryInMinutes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VMwareToAzStackHCIPolicyModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class VMwareToAzStackHCIPolicyModelCustomPropertiesArgsBuilder internal constructor() {
    private var appConsistentFrequencyInMinutes: Output<Int>? = null

    private var crashConsistentFrequencyInMinutes: Output<Int>? = null

    private var instanceType: Output<String>? = null

    private var recoveryPointHistoryInMinutes: Output<Int>? = null

    /**
     * @param value Gets or sets the app consistent snapshot frequency (in minutes).
     */
    @JvmName("ttctdopglwpdakwh")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.appConsistentFrequencyInMinutes = value
    }

    /**
     * @param value Gets or sets the crash consistent snapshot frequency (in minutes).
     */
    @JvmName("omrxkcanlrqppxun")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.crashConsistentFrequencyInMinutes = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("cgwhrlcevauoweey")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the duration in minutes until which the recovery points need to be
     * stored.
     */
    @JvmName("nfecetisqjejqoys")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Output<Int>) {
        this.recoveryPointHistoryInMinutes = value
    }

    /**
     * @param value Gets or sets the app consistent snapshot frequency (in minutes).
     */
    @JvmName("thvhpeassfvfskhr")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value Gets or sets the crash consistent snapshot frequency (in minutes).
     */
    @JvmName("ssqffnmobhnrikad")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.crashConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("gumdlorpuidspqqp")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the duration in minutes until which the recovery points need to be
     * stored.
     */
    @JvmName("yaanpjqecndqmusa")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recoveryPointHistoryInMinutes = mapped
    }

    internal fun build(): VMwareToAzStackHCIPolicyModelCustomPropertiesArgs =
        VMwareToAzStackHCIPolicyModelCustomPropertiesArgs(
            appConsistentFrequencyInMinutes = appConsistentFrequencyInMinutes ?: throw
                PulumiNullFieldException("appConsistentFrequencyInMinutes"),
            crashConsistentFrequencyInMinutes = crashConsistentFrequencyInMinutes ?: throw
                PulumiNullFieldException("crashConsistentFrequencyInMinutes"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            recoveryPointHistoryInMinutes = recoveryPointHistoryInMinutes ?: throw
                PulumiNullFieldException("recoveryPointHistoryInMinutes"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/VMwareToAzStackHCIPolicyModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMware To AzStackHCI Policy model custom properties.
 * @property appConsistentFrequencyInMinutes Gets or sets the app consistent snapshot frequency (in minutes).
 * @property crashConsistentFrequencyInMinutes Gets or sets the crash consistent snapshot frequency (in minutes).
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'VMwareToAzStackHCI'.
 * @property recoveryPointHistoryInMinutes Gets or sets the duration in minutes until which the recovery points need to be
 * stored.
 */
public data class VMwareToAzStackHCIPolicyModelCustomPropertiesArgs(
    public val appConsistentFrequencyInMinutes: Output<Int>,
    public val crashConsistentFrequencyInMinutes: Output<Int>,
    public val instanceType: Output<String>,
    public val recoveryPointHistoryInMinutes: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIPolicyModelCustomPropertiesArgs.builder()
            .appConsistentFrequencyInMinutes(appConsistentFrequencyInMinutes.applyValue({ args0 -> args0 }))
            .crashConsistentFrequencyInMinutes(crashConsistentFrequencyInMinutes.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .recoveryPointHistoryInMinutes(recoveryPointHistoryInMinutes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VMwareToAzStackHCIPolicyModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class VMwareToAzStackHCIPolicyModelCustomPropertiesArgsBuilder internal constructor() {
    private var appConsistentFrequencyInMinutes: Output<Int>? = null

    private var crashConsistentFrequencyInMinutes: Output<Int>? = null

    private var instanceType: Output<String>? = null

    private var recoveryPointHistoryInMinutes: Output<Int>? = null

    /**
     * @param value Gets or sets the app consistent snapshot frequency (in minutes).
     */
    @JvmName("mkcnhhiynfiykcig")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.appConsistentFrequencyInMinutes = value
    }

    /**
     * @param value Gets or sets the crash consistent snapshot frequency (in minutes).
     */
    @JvmName("hhgwraqbcodjkmxv")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.crashConsistentFrequencyInMinutes = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("amlgqbhxemwuvsaa")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the duration in minutes until which the recovery points need to be
     * stored.
     */
    @JvmName("eetjjlotgylblikh")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Output<Int>) {
        this.recoveryPointHistoryInMinutes = value
    }

    /**
     * @param value Gets or sets the app consistent snapshot frequency (in minutes).
     */
    @JvmName("khyqlaikyyohxmtu")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value Gets or sets the crash consistent snapshot frequency (in minutes).
     */
    @JvmName("qyredgvbjwmstqdf")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.crashConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("hdbwykenjovigiel")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the duration in minutes until which the recovery points need to be
     * stored.
     */
    @JvmName("npjeieeejodafvac")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recoveryPointHistoryInMinutes = mapped
    }

    internal fun build(): VMwareToAzStackHCIPolicyModelCustomPropertiesArgs =
        VMwareToAzStackHCIPolicyModelCustomPropertiesArgs(
            appConsistentFrequencyInMinutes = appConsistentFrequencyInMinutes ?: throw
                PulumiNullFieldException("appConsistentFrequencyInMinutes"),
            crashConsistentFrequencyInMinutes = crashConsistentFrequencyInMinutes ?: throw
                PulumiNullFieldException("crashConsistentFrequencyInMinutes"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            recoveryPointHistoryInMinutes = recoveryPointHistoryInMinutes ?: throw
                PulumiNullFieldException("recoveryPointHistoryInMinutes"),
        )
}
